OpenFileResult class
Constructors
- OpenFileResult(String path)
Properties
- data ↔ String
-
文件二进制数据(延迟加载)
latefinal
- extension ↔ String
-
文件扩展名(pdf / jpg / png)
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String
-
mime 类型(如 application/pdf)
latefinal
- name ↔ String
-
文件名
latefinal
- path → String
-
原始文件路径
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
文件大小(字节)
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readData(
) → Future< String> - 延迟读取文件数据(避免冷启动卡顿)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited